@@ -2,12 +2,11 @@ package HTTP::Request::Diff;
 use 5.020;
 use Moo 2;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
-use feature 'signatures';
-use feature 'postderef';
+use experimental 'signatures'; # actually, they are stable but stable.pm doesn't know
+use stable 'postderef';
 no warnings 'experimental::signatures';
-no warnings 'experimental::postderef';
 use Algorithm::Diff;
 use Carp 'croak', 'cluck';
 use List::Util 'pairs', 'uniq', 'max';
